.. -*- mode: rst -*-
.. ex: set sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the NiBabel package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###

.. include:: _long_description.inc

Documentation
=============

* :ref:`User Documentation <manual>` (manual)
* :ref:`Tutorials <tutorials>` (relevant tutorials on imaging)
* :ref:`API Documentation <api>` (comprehensive reference)
* :ref:`Developer Guidelines <chap_devguide>` (for those who want to contribute)
* :ref:`Development Changelog <changelog>` (see what has changed)
* :ref:`DICOM concepts <dicom>` (details about implementing DICOM reading)
* :ref:`genindex` (access by keywords)
* :ref:`search` (online and offline full-text search)

See also the :ref:`Developer documentation page <devindex>` for development
discussions, release procedure and more.

Authors and Contributors
========================

Most work on NiBabel so far has been by `Matthew Brett`_, Chris Markiewicz,
`Michael Hanke`_, `Marc-Alexandre Côté`_, `Ben Cipollini`_, Paul McCarthy and
Chris Cheng.  The authors are grateful to the following people who have
contributed code and discussion (in rough order of appearance):

* `Yaroslav O. Halchenko`_
* Chris Burns
* `Gaël Varoquaux`_
* Ian Nimmo-Smith
* `Jarrod Millman`_
* `Bertrand Thirion`_
* Thomas Ballinger
* Cindee Madison
* Valentin Haenel
* `Alexandre Gramfort`_
* Christian Haselgrove
* Krish Subramaniam
* Yannick Schwartz
* Bago Amirbekian
* Brendan Moloney
* Félix C. Morency
* JB Poline
* Basile Pinsard
* `Satrajit Ghosh`_
* `Nolan Nichols`_
* Ly Nguyen
* Philippe Gervais
* Demian Wassermann
* Justin Lecher
* Oliver P. Hinds
* Nikolaas N. Oosterhof
* Kevin S. Hahn
* Michiel Cottaar
* Erik Kastman
* Github user ``freec84``
* Peter Fischer
* Clemens C. C. Bauer
* Samuel St-Jean
* Gregory R. Lee
* Eric M. Baker
* `Ariel Rokem`_
* Eleftherios Garyfallidis
* Jaakko Leppäkangas
* Syam Gadde
* Robert D. Vincent
* Ivan Gonzalez
* Demian Wassermann
* Paul McCarthy
* Fernando Pérez García
* Venky Reddy
* Mark Hymers
* Jasper J.F. van den Bosch
* Bennet Fauber
* Kesshi Jordan
* Jon Stutters
* Serge Koudoro
* Christopher P. Cheng
* Mathias Goncalves
* Jakub Kaczmarzyk
* Dimitri Papadopoulos Orfanos
* Ross Markello
* Miguel Estevan Moreno
* Thomas Roos
* Igor Solovey
* Jon Haitz Legarreta Gorroño
* Katrin Leinweber
* Soichi Hayashi
* Samir Reddigari
* Konstantinos Raktivan
* Matt Cieslak
* Egor Panfilov
* Jath Palasubramaniam
* Henry Braun
* Oscar Esteban
* Cameron Riddell
* Hao-Ting Wang
* Dorota Jarecka
* Chris Gorgolewski
* Benjamin C Darwin
* Zvi Baratz
* Roberto Guidotti
* Or Duek
* Anibal Sólon
* Jonathan Daniel
* Markéta Calábková
* Carl Gauthier
* Julian Klug
* Lea Waller
* Tomáš Hrnčiar
* Andrew Van
* Jérôme Dockès
* Jacob Roberts

License reprise
===============

NiBabel is free-software (beer and speech) and covered by the `MIT License`_.
This applies to all source code, documentation, examples and snippets inside
the source distribution (including this website). Please see the
:ref:`appendix of the manual <license>` for the copyright statement and the
full text of the license.

Download and Installation
=========================

Please find detailed :ref:`download and installation instructions
<installation>` in the manual.

Support
=======

If you have problems installing the software or questions about usage,
documentation or anything else related to NiBabel, you can post to the NiPy
mailing list.

:Mailing list:  neuroimaging@python.org [subscription_, archive_]

We recommend that anyone using NiBabel subscribes to the mailing list.  The
mailing list is the preferred way to announce changes and additions to the
project. You can also search the mailing list archive using the *mailing list
archive search* located in the sidebar of the NiBabel home page.

.. _subscription: https://mail.python.org/mailman/listinfo/neuroimaging
.. _archive: https://mail.python.org/pipermail/neuroimaging

.. include:: links_names.txt


.. toctree::
   :hidden:

   manual
   tutorials
   devel/index
   dicom/dicom
   api
